==> core-1.70.0-sources.jar: software/amazon/awscdk/core/BootstraplessSynthesizerProps.java <==
package software.amazon.awscdk.core;

/**
 * Construction properties of {@link BootstraplessSynthesizer}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-23T23:56:37.133Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.BootstraplessSynthesizerProps")
@software.amazon.jsii.Jsii.Proxy(BootstraplessSynthesizerProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BootstraplessSynthesizerProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The CFN execution Role ARN to use.
     * <p>
     * Default: - No CloudFormation role (use CLI credentials)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCloudFormationExecutionRoleArn() {
        return null;
    }

    /**
     * The deploy Role ARN to use.
     * <p>
     * Default: - No deploy role (use CLI credentials)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDeployRoleArn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BootstraplessSynthesizerProps> {
        private java.lang.String cloudFormationExecutionRoleArn;
        private java.lang.String deployRoleArn;

        /**
         * Sets the value of {@link BootstraplessSynthesizerProps#getCloudFormationExecutionRoleArn}
         * @param cloudFormationExecutionRoleArn The CFN execution Role ARN to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudFormationExecutionRoleArn(java.lang.String cloudFormationExecutionRoleArn) {
            this.cloudFormationExecutionRoleArn = cloudFormationExecutionRoleArn;
            return this;
        }

        /**
         * Sets the value of {@link BootstraplessSynthesizerProps#getDeployRoleArn}
         * @param deployRoleArn The deploy Role ARN to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployRoleArn(java.lang.String deployRoleArn) {
            this.deployRoleArn = deployRoleArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BootstraplessSynthesizerProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BootstraplessSynthesizerProps build() {
            return new Jsii$Proxy(cloudFormationExecutionRoleArn, deployRoleArn);
        }
    }

    /**
     * An implementation for {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BootstraplessSynthesizerProps {
        private final java.lang.String cloudFormationExecutionRoleArn;
        private final java.lang.String deployRoleArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudFormationExecutionRoleArn = this.jsiiGet("cloudFormationExecutionRoleArn", java.lang.String.class);
            this.deployRoleArn = this.jsiiGet("deployRoleArn", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String cloudFormationExecutionRoleArn, final java.lang.String deployRoleArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudFormationExecutionRoleArn = cloudFormationExecutionRoleArn;
            this.deployRoleArn = deployRoleArn;
        }

        @Override
        public java.lang.String getCloudFormationExecutionRoleArn() {
            return this.cloudFormationExecutionRoleArn;
        }

        @Override
        public java.lang.String getDeployRoleArn() {
            return this.deployRoleArn;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudFormationExecutionRoleArn() != null) {
                data.set("cloudFormationExecutionRoleArn", om.valueToTree(this.getCloudFormationExecutionRoleArn()));
            }
            if (this.getDeployRoleArn() != null) {
                data.set("deployRoleArn", om.valueToTree(this.getDeployRoleArn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.BootstraplessSynthesizerProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BootstraplessSynthesizerProps.Jsii$Proxy that = (BootstraplessSynthesizerProps.Jsii$Proxy) o;

            if (this.cloudFormationExecutionRoleArn != null ? !this.cloudFormationExecutionRoleArn.equals(that.cloudFormationExecutionRoleArn) : that.cloudFormationExecutionRoleArn != null) return false;
            return this.deployRoleArn != null ? this.deployRoleArn.equals(that.deployRoleArn) : that.deployRoleArn == null;
        }

        @Override
        public int hashCode() {
            int result = this.cloudFormationExecutionRoleArn != null ? this.cloudFormationExecutionRoleArn.hashCode() : 0;
            result = 31 * result + (this.deployRoleArn != null ? this.deployRoleArn.hashCode() : 0);
            return result;
        }
    }
}

==> core-1.71.0-sources.jar: software/amazon/awscdk/core/BootstraplessSynthesizerProps.java <==
package software.amazon.awscdk.core;

/**
 * Construction properties of {@link BootstraplessSynthesizer}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.14.0 (build 729554b)", date = "2020-10-29T17:33:53.207Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.BootstraplessSynthesizerProps")
@software.amazon.jsii.Jsii.Proxy(BootstraplessSynthesizerProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BootstraplessSynthesizerProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The CFN execution Role ARN to use.
     * <p>
     * Default: - No CloudFormation role (use CLI credentials)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCloudFormationExecutionRoleArn() {
        return null;
    }

    /**
     * The deploy Role ARN to use.
     * <p>
     * Default: - No deploy role (use CLI credentials)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDeployRoleArn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BootstraplessSynthesizerProps> {
        private java.lang.String cloudFormationExecutionRoleArn;
        private java.lang.String deployRoleArn;

        /**
         * Sets the value of {@link BootstraplessSynthesizerProps#getCloudFormationExecutionRoleArn}
         * @param cloudFormationExecutionRoleArn The CFN execution Role ARN to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudFormationExecutionRoleArn(java.lang.String cloudFormationExecutionRoleArn) {
            this.cloudFormationExecutionRoleArn = cloudFormationExecutionRoleArn;
            return this;
        }

        /**
         * Sets the value of {@link BootstraplessSynthesizerProps#getDeployRoleArn}
         * @param deployRoleArn The deploy Role ARN to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployRoleArn(java.lang.String deployRoleArn) {
            this.deployRoleArn = deployRoleArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BootstraplessSynthesizerProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BootstraplessSynthesizerProps build() {
            return new Jsii$Proxy(cloudFormationExecutionRoleArn, deployRoleArn);
        }
    }

    /**
     * An implementation for {@link BootstraplessSynthesizerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BootstraplessSynthesizerProps {
        private final java.lang.String cloudFormationExecutionRoleArn;
        private final java.lang.String deployRoleArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudFormationExecutionRoleArn = software.amazon.jsii.Kernel.get(this, "cloudFormationExecutionRoleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.deployRoleArn = software.amazon.jsii.Kernel.get(this, "deployRoleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String cloudFormationExecutionRoleArn, final java.lang.String deployRoleArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudFormationExecutionRoleArn = cloudFormationExecutionRoleArn;
            this.deployRoleArn = deployRoleArn;
        }

        @Override
        public final java.lang.String getCloudFormationExecutionRoleArn() {
            return this.cloudFormationExecutionRoleArn;
        }

        @Override
        public final java.lang.String getDeployRoleArn() {
            return this.deployRoleArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudFormationExecutionRoleArn() != null) {
                data.set("cloudFormationExecutionRoleArn", om.valueToTree(this.getCloudFormationExecutionRoleArn()));
            }
            if (this.getDeployRoleArn() != null) {
                data.set("deployRoleArn", om.valueToTree(this.getDeployRoleArn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.BootstraplessSynthesizerProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BootstraplessSynthesizerProps.Jsii$Proxy that = (BootstraplessSynthesizerProps.Jsii$Proxy) o;

            if (this.cloudFormationExecutionRoleArn != null ? !this.cloudFormationExecutionRoleArn.equals(that.cloudFormationExecutionRoleArn) : that.cloudFormationExecutionRoleArn != null) return false;
            return this.deployRoleArn != null ? this.deployRoleArn.equals(that.deployRoleArn) : that.deployRoleArn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudFormationExecutionRoleArn != null ? this.cloudFormationExecutionRoleArn.hashCode() : 0;
            result = 31 * result + (this.deployRoleArn != null ? this.deployRoleArn.hashCode() : 0);
            return result;
        }
    }
}
